## Description

Please provide a clear and concise description of the changes introduced in this PR. Include any relevant context or motivation.

Fixes #(issue number)  
Closes #(issue number)  

---

## Type of Change

Please check the type(s) of changes made in this PR:

- [ ] Bug Fix (non-breaking change that fixes an issue)
- [ ] New Feature (non-breaking change that adds functionality)
- [ ] Breaking Change (fix or feature that would cause existing functionality to not work as expected)
- [ ] Documentation Update (adds or updates documentation)
- [ ] Refactor (code restructuring without changing external behaviour)
- [ ] Other (please specify):  

- For non-breaking changes remember to run `tox`to test against older qiskit versions.

---

## Checklist

Please check all relevant boxes to ensure your pull request is ready for review:

- [ ] I have tested my changes locally and they work as expected.
    * For changes that should be backwards compatible to older Qiskit versions run `tox` in addition to pytest tests ran by CI
- [ ] I have added/updated relevant documentation (if applicable).
- [ ] I have formatted my code using the project’s coding style or linter.
- [ ] I have added tests that prove my fix is effective or my feature works (if applicable).
- [ ] All new and existing tests pass.
- [ ] My code follows the [CONTRIBUTING.md](../CONTRIBUTING.md) guidelines.

---

## Screenshots (if applicable)

Include screenshots if relevant. E.g. of new graphs or other pictures in documentation etc.

---

## Additional Notes

Include any additional comments, questions, or concerns here. If the PR is a work in progress (WIP), mention what still needs to be done.
